@@ -742,7 +742,7 @@ func TestBuildWithGitSubmoduleModified(t *testing.T) {
 		submoduleReadme := filepath.Join(submoduleDir, "README.md")
 
 		// modify submodule and commit
-		modifySubmoduleBeforeCommit := "commited change"
+		modifySubmoduleBeforeCommit := "committed change"
 		err = ioutil.WriteFile(submoduleReadme, []byte(modifySubmoduleBeforeCommit), os.ModeSticky)
 		require.NoError(t, err)
 		_, err = gitInDir(submoduleDir, "add", "README.md")
@@ -1088,47 +1088,3 @@ func TestBuildWithGitCleanFlags(t *testing.T) {
 		assert.Error(t, err, "cleanup_file does not exist")
 	})
 }
-
-// TODO: Remove in 12.0
-func TestBuildNoRefspecs(t *testing.T) {
-	strategies := []string{"clone", "fetch", "none"}
-	expectedOutputs := map[string]string{
-		"clone": "Cloning repository...",
-		"fetch": "Fetching changes...",
-		"none":  "Skipping Git repository setup",
-	}
-
-	shellstest.OnEachShell(t, func(t *testing.T, shell string) {
-		for _, strategy := range strategies {
-			t.Run(fmt.Sprintf("GIT_STRATEGY %s", strategy), func(t *testing.T) {
-				apiBuild, err := common.GetSuccessfulBuild()
-				assert.NoError(t, err)
-
-				apiBuild.GitInfo.Refspecs = []string{}
-				build, cleanup := newBuild(t, apiBuild, shell)
-				defer cleanup()
-
-				build.Variables = append(build.Variables, common.JobVariable{Key: "GIT_STRATEGY", Value: strategy})
-
-				expectedOutput, ok := expectedOutputs[strategy]
-				require.True(t, ok, "missing expectancies for %s strategy", strategy)
-
-				err = runBuild(t, build)
-				require.NoError(t, err)
-
-				// run twice because script behavior changes based on build directory existence
-				out, err := runBuildReturningOutput(t, build)
-				require.NoError(t, err)
-				require.Contains(t, out, expectedOutput)
-
-				for s, notExpected := range expectedOutputs {
-					if s == strategy {
-						continue
-					}
-
-					require.NotContains(t, out, notExpected)
-				}
-			})
-		}
-	})
-}
