@@ -146,16 +146,16 @@ func TestRegisterRunner(t *testing.T) {
 		assert.Equal(t, validToken.Token, res.Token)
 	}
 
-	res = c.RegisterRunner(validToken, RegisterRunnerParameters{Description: "invalid description", Tags: "tags", RunUntagged: true, Locked: true, Active: true})
+	res = c.RegisterRunner(validToken, RegisterRunnerParameters{Description: "invalid description", Tags: "tags", RunUntagged: true, Locked: true, AccessLevel: "not_protected", Active: true})
 	assert.Nil(t, res)
 
-	res = c.RegisterRunner(invalidToken, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, Active: true})
+	res = c.RegisterRunner(invalidToken, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, AccessLevel: "not_protected", Active: true})
 	assert.Nil(t, res)
 
-	res = c.RegisterRunner(otherToken, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, Active: true})
+	res = c.RegisterRunner(otherToken, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, AccessLevel: "not_protected", Active: true})
 	assert.Nil(t, res)
 
-	res = c.RegisterRunner(brokenCredentials, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, Active: true})
+	res = c.RegisterRunner(brokenCredentials, RegisterRunnerParameters{Description: "test", Tags: "tags", RunUntagged: true, Locked: true, AccessLevel: "not_protected", Active: true})
 	assert.Nil(t, res)
 }
 
@@ -765,12 +765,12 @@ func TestRangeMismatchPatchTrace(t *testing.T) {
 	endOffset, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
 		patchTraceContent[11:], 11)
 	assert.Equal(t, UpdateRangeMismatch, state)
-	assert.Equal(t, 10, endOffset) // TODO: (kamil) to verify behavior
+	assert.Equal(t, 10, endOffset)
 
 	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
 		patchTraceContent[15:], 15)
 	assert.Equal(t, UpdateRangeMismatch, state)
-	assert.Equal(t, 10, endOffset) // TODO: (kamil) to verify behavior
+	assert.Equal(t, 10, endOffset)
 
 	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
 		patchTraceContent[5:], 5)
